==> react-molecule-photo-uploader-1.8.0.tgz: package/lib/PhotosPreview.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ReactSortable } from 'react-sortablejs';
import ThumbCard from './ThumbCard';
import SkeletonCard from './SkeletonCard';
import { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { formatToBase64, cropAndRotateImage, base64ToBlob } from './photoTools';
import { BASE_CLASS_NAME, THUMB_CLASS_NAME, THUMB_SORTABLE_CLASS_NAME, DEFAULT_NOTIFICATION_ERROR, DEFAULT_HAS_ERRORS_STATUS, DEFAULT_IMAGE_ROTATION_DEGREES, ROTATION_DIRECTION, DEFAULT_IMAGE_ASPECT_RATIO, DEFAULT_MAX_IMAGE_HEIGHT, DEFAULT_MAX_IMAGE_WIDTH } from './config';
var PREVIEW_CARD_CLASS_NAME = BASE_CLASS_NAME + "-preview";

var PhotosPreview = function PhotosPreview(_ref) {
  var _cx, _cx2;

  var _callbackPhotosUploaded = _ref._callbackPhotosUploaded,
      _scrollToBottom = _ref._scrollToBottom,
      addMorePhotosIcon = _ref.addMorePhotosIcon,
      addPhotoTextSkeleton = _ref.addPhotoTextSkeleton,
      defaultFormatToBase64Options = _ref.defaultFormatToBase64Options,
      deleteIcon = _ref.deleteIcon,
      dragDelay = _ref.dragDelay,
      errorInitialPhotoDownloadErrorText = _ref.errorInitialPhotoDownloadErrorText,
      files = _ref.files,
      isPhotoUploaderFully = _ref.isPhotoUploaderFully,
      mainPhotoLabel = _ref.mainPhotoLabel,
      outputImageAspectRatioDisabled = _ref.outputImageAspectRatioDisabled,
      rejectPhotosIcon = _ref.rejectPhotosIcon,
      rotateIcon = _ref.rotateIcon,
      rotationDirection = _ref.rotationDirection,
      retryIcon = _ref.retryIcon,
      setFiles = _ref.setFiles,
      setIsLoading = _ref.setIsLoading,
      setNotificationError = _ref.setNotificationError,
      thumbIconSize = _ref.thumbIconSize;

  var _onSortEnd = function _onSortEnd() {
    _callbackPhotosUploaded(files);
  };

  var _deleteItem = function _deleteItem(index) {
    var list = [].concat(files);
    list.splice(index, 1);
    setFiles(list);
    setNotificationError(DEFAULT_NOTIFICATION_ERROR);

    _callbackPhotosUploaded(list);
  };

  var _rotateItem = function _rotateItem(index) {
    var list = [].concat(files);

    if (rotationDirection === ROTATION_DIRECTION.clockwise) {
      list[index].rotation = list[index].rotation === 270 ? 0 : list[index].rotation + 90;
    } else {
      list[index].rotation = list[index].rotation === 0 ? 270 : list[index].rotation - 90;
    }

    cropAndRotateImage({
      base64Image: list[index].originalBase64,
      rotation: list[index].rotation,
      outputImageAspectRatio: DEFAULT_IMAGE_ASPECT_RATIO,
      maxImageHeight: DEFAULT_MAX_IMAGE_HEIGHT,
      maxImageWidth: DEFAULT_MAX_IMAGE_WIDTH,
      outputImageAspectRatioDisabled: outputImageAspectRatioDisabled
    }).then(function (value) {
      return base64ToBlob(value);
    }).then(function (_ref2) {
      var blob = _ref2.blob,
          base64 = _ref2.base64;
      list[index].preview = base64;
      list[index].blob = blob;
      setFiles(list);
      list[index].isModified = true;
      setNotificationError(DEFAULT_NOTIFICATION_ERROR);

      _callbackPhotosUploaded(list);
    });
  };

  var _retryUpload = function _retryUpload(index) {
    setIsLoading(true);

    var _files = [].concat(files);

    var photoToRetry = _files[index];
    formatToBase64({
      url: photoToRetry.url,
      options: defaultFormatToBase64Options
    }).then(function (_ref3) {
      var blob = _ref3.blob,
          croppedBase64 = _ref3.croppedBase64,
          url = _ref3.url,
          _ref3$hasErrors = _ref3.hasErrors,
          hasErrors = _ref3$hasErrors === void 0 ? DEFAULT_HAS_ERRORS_STATUS : _ref3$hasErrors;

      if (hasErrors) {
        setNotificationError({
          isError: true,
          text: errorInitialPhotoDownloadErrorText
        });

        _scrollToBottom();
      } else {
        setNotificationError(DEFAULT_NOTIFICATION_ERROR);
      }

      _files[index] = {
        blob: blob,
        url: url,
        hasErrors: hasErrors,
        originalBase64: croppedBase64,
        preview: croppedBase64,
        rotation: DEFAULT_IMAGE_ROTATION_DEGREES,
        isNew: false,
        isModified: false
      };
      setFiles([].concat(_files));

      _callbackPhotosUploaded(_files);

      setIsLoading(false);
    });
  };

  var thumbClassName = cx(THUMB_CLASS_NAME, (_cx = {}, _cx[THUMB_SORTABLE_CLASS_NAME] = files.length > 1, _cx));

  var thumbCards = function thumbCards(files) {
    return files.map(function (file, index) {
      return /*#__PURE__*/React.createElement("li", {
        className: thumbClassName,
        key: "" + file.preview + index,
        onClick: function onClick(e) {
          return e.stopPropagation();
        }
      }, /*#__PURE__*/React.createElement(ThumbCard, {
        iconSize: thumbIconSize,
        image: file,
        index: index,
        mainPhotoLabel: mainPhotoLabel,
        callbackDeleteItem: _deleteItem,
        callbackRetryUpload: _retryUpload,
        callbackRotateItem: _rotateItem,
        rotateIcon: rotateIcon(),
        deleteIcon: deleteIcon(),
        retryIcon: retryIcon(),
        rejectPhotosIcon: rejectPhotosIcon(),
        outputImageAspectRatioDisabled: outputImageAspectRatioDisabled
      }));
    });
  };

  var previewCardClass = cx(PREVIEW_CARD_CLASS_NAME, (_cx2 = {}, _cx2[PREVIEW_CARD_CLASS_NAME + "--ratioDisabled"] = outputImageAspectRatioDisabled, _cx2));
  return /*#__PURE__*/React.createElement(ReactSortable, {
    className: previewCardClass,
    handle: ".sui-MoleculePhotoUploader-thumbCard-imageContainer",
    ghostClass: THUMB_CLASS_NAME + "--ghost",
    dragClass: THUMB_CLASS_NAME + "--drag",
    chosenClass: THUMB_CLASS_NAME + "--chosen",
    tag: "ul",
    list: files,
    setList: setFiles,
    animation: 200,
    draggable: "." + THUMB_SORTABLE_CLASS_NAME,
    onEnd: function onEnd() {
      return _onSortEnd();
    },
    delay: dragDelay
  }, /*#__PURE__*/React.createElement(React.Fragment, null, thumbCards(files), !isPhotoUploaderFully() && /*#__PURE__*/React.createElement(SkeletonCard, {
    icon: addMorePhotosIcon(),
    text: addPhotoTextSkeleton
  })));
};

PhotosPreview.displayName = 'PhotosPreview';
export default PhotosPreview;

==> react-molecule-photo-uploader-1.13.0.tgz: package/lib/PhotosPreview.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { ReactSortable } from 'react-sortablejs';
import ThumbCard from './ThumbCard';
import SkeletonCard from './SkeletonCard';
import { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { formatToBase64, cropAndRotateImage, base64ToBlob } from './photoTools';
import { BASE_CLASS_NAME, THUMB_CLASS_NAME, THUMB_SORTABLE_CLASS_NAME, DEFAULT_NOTIFICATION_ERROR, DEFAULT_HAS_ERRORS_STATUS, DEFAULT_IMAGE_ROTATION_DEGREES, ROTATION_DIRECTION, DEFAULT_IMAGE_ASPECT_RATIO, DEFAULT_MAX_IMAGE_HEIGHT, DEFAULT_MAX_IMAGE_WIDTH } from './config';
var PREVIEW_CARD_CLASS_NAME = BASE_CLASS_NAME + "-preview";

var PhotosPreview = function PhotosPreview(_ref) {
  var _cx, _cx2;

  var _callbackPhotosUploaded = _ref._callbackPhotosUploaded,
      _scrollToBottom = _ref._scrollToBottom,
      addMorePhotosIcon = _ref.addMorePhotosIcon,
      addPhotoTextSkeleton = _ref.addPhotoTextSkeleton,
      defaultFormatToBase64Options = _ref.defaultFormatToBase64Options,
      deleteIcon = _ref.deleteIcon,
      dragDelay = _ref.dragDelay,
      errorInitialPhotoDownloadErrorText = _ref.errorInitialPhotoDownloadErrorText,
      files = _ref.files,
      isPhotoUploaderFully = _ref.isPhotoUploaderFully,
      mainPhotoLabel = _ref.mainPhotoLabel,
      outputImageAspectRatioDisabled = _ref.outputImageAspectRatioDisabled,
      rejectPhotosIcon = _ref.rejectPhotosIcon,
      rotateIcon = _ref.rotateIcon,
      rotationDirection = _ref.rotationDirection,
      retryIcon = _ref.retryIcon,
      setFiles = _ref.setFiles,
      setIsLoading = _ref.setIsLoading,
      setNotificationError = _ref.setNotificationError,
      thumbIconSize = _ref.thumbIconSize;

  var _onSortEnd = function _onSortEnd() {
    _callbackPhotosUploaded(files);
  };

  var _deleteItem = function _deleteItem(index) {
    var list = [].concat(files);
    list.splice(index, 1);
    setFiles(list);
    setNotificationError(DEFAULT_NOTIFICATION_ERROR);

    _callbackPhotosUploaded(list);
  };

  var _rotateItem = function _rotateItem(index) {
    var list = [].concat(files);

    if (rotationDirection === ROTATION_DIRECTION.clockwise) {
      list[index].rotation = list[index].rotation === 270 ? 0 : list[index].rotation + 90;
    } else {
      list[index].rotation = list[index].rotation === 0 ? 270 : list[index].rotation - 90;
    }

    cropAndRotateImage({
      base64Image: list[index].originalBase64,
      rotation: list[index].rotation,
      outputImageAspectRatio: DEFAULT_IMAGE_ASPECT_RATIO,
      maxImageHeight: DEFAULT_MAX_IMAGE_HEIGHT,
      maxImageWidth: DEFAULT_MAX_IMAGE_WIDTH,
      outputImageAspectRatioDisabled: outputImageAspectRatioDisabled
    }).then(function (value) {
      return base64ToBlob(value);
    }).then(function (_ref2) {
      var blob = _ref2.blob,
          base64 = _ref2.base64;
      list[index].preview = base64;
      list[index].blob = blob;
      setFiles(list);
      list[index].isModified = true;
      setNotificationError(DEFAULT_NOTIFICATION_ERROR);

      _callbackPhotosUploaded(list);
    });
  };

  var _retryUpload = function _retryUpload(index) {
    setIsLoading(true);

    var _files = [].concat(files);

    var photoToRetry = _files[index];
    formatToBase64({
      url: photoToRetry.url,
      options: defaultFormatToBase64Options
    }).then(function (_ref3) {
      var blob = _ref3.blob,
          croppedBase64 = _ref3.croppedBase64,
          url = _ref3.url,
          _ref3$hasErrors = _ref3.hasErrors,
          hasErrors = _ref3$hasErrors === void 0 ? DEFAULT_HAS_ERRORS_STATUS : _ref3$hasErrors;

      if (hasErrors) {
        setNotificationError({
          isError: true,
          text: errorInitialPhotoDownloadErrorText
        });

        _scrollToBottom();
      } else {
        setNotificationError(DEFAULT_NOTIFICATION_ERROR);
      }

      _files[index] = {
        blob: blob,
        url: url,
        hasErrors: hasErrors,
        originalBase64: croppedBase64,
        preview: croppedBase64,
        rotation: DEFAULT_IMAGE_ROTATION_DEGREES,
        isNew: false,
        isModified: false
      };
      setFiles([].concat(_files));

      _callbackPhotosUploaded(_files);

      setIsLoading(false);
    });
  };

  var thumbClassName = cx(THUMB_CLASS_NAME, (_cx = {}, _cx[THUMB_SORTABLE_CLASS_NAME] = files.length > 1, _cx));

  var thumbCards = function thumbCards(files) {
    return files.map(function (file, index) {
      return React.createElement("li", {
        className: thumbClassName,
        key: "" + file.preview + index,
        onClick: function onClick(e) {
          return e.stopPropagation();
        }
      }, React.createElement(ThumbCard, {
        iconSize: thumbIconSize,
        image: file,
        index: index,
        mainPhotoLabel: mainPhotoLabel,
        callbackDeleteItem: _deleteItem,
        callbackRetryUpload: _retryUpload,
        callbackRotateItem: _rotateItem,
        rotateIcon: rotateIcon(),
        deleteIcon: deleteIcon(),
        retryIcon: retryIcon(),
        rejectPhotosIcon: rejectPhotosIcon(),
        outputImageAspectRatioDisabled: outputImageAspectRatioDisabled
      }));
    });
  };

  var previewCardClass = cx(PREVIEW_CARD_CLASS_NAME, (_cx2 = {}, _cx2[PREVIEW_CARD_CLASS_NAME + "--ratioDisabled"] = outputImageAspectRatioDisabled, _cx2));
  return React.createElement(ReactSortable, {
    className: previewCardClass,
    handle: ".sui-MoleculePhotoUploader-thumbCard-imageContainer",
    ghostClass: THUMB_CLASS_NAME + "--ghost",
    dragClass: THUMB_CLASS_NAME + "--drag",
    chosenClass: THUMB_CLASS_NAME + "--chosen",
    tag: "ul",
    list: files,
    setList: setFiles,
    animation: 200,
    draggable: "." + THUMB_SORTABLE_CLASS_NAME,
    onEnd: function onEnd() {
      return _onSortEnd();
    },
    delay: dragDelay
  }, React.createElement(React.Fragment, null, thumbCards(files), !isPhotoUploaderFully() && React.createElement(SkeletonCard, {
    icon: addMorePhotosIcon(),
    text: addPhotoTextSkeleton
  })));
};

PhotosPreview.displayName = 'PhotosPreview';
export default PhotosPreview;
